@@ -836,3 +836,162 @@ class Normalizer(object):
         for server_usage in server_usages:
             ret.append(self._normalize_server_usage(server_usage))
         return ret
+
+    def _normalize_cluster_templates(self, cluster_templates):
+        ret = []
+        for cluster_template in cluster_templates:
+            ret.append(self._normalize_cluster_template(cluster_template))
+        return ret
+
+    def _normalize_cluster_template(self, cluster_template):
+        """Normalize Magnum cluster_templates."""
+        cluster_template = cluster_template.copy()
+
+        # Discard noise
+        cluster_template.pop('links', None)
+        cluster_template.pop('human_id', None)
+        # model_name is a magnumclient-ism
+        cluster_template.pop('model_name', None)
+
+        ct_id = cluster_template.pop('uuid')
+
+        ret = munch.Munch(
+            id=ct_id,
+            location=self._get_current_location(),
+        )
+        ret['is_public'] = cluster_template.pop('public')
+        ret['is_registry_enabled'] = cluster_template.pop('registry_enabled')
+        ret['is_tls_disabled'] = cluster_template.pop('tls_disabled')
+        # pop floating_ip_enabled since we want to hide it in a future patch
+        fip_enabled = cluster_template.pop('floating_ip_enabled', None)
+        if not self.strict_mode:
+            ret['uuid'] = ct_id
+            if fip_enabled is not None:
+                ret['floating_ip_enabled'] = fip_enabled
+            ret['public'] = ret['is_public']
+            ret['registry_enabled'] = ret['is_registry_enabled']
+            ret['tls_disabled'] = ret['is_tls_disabled']
+
+        # Optional keys
+        for (key, default) in (
+                ('fixed_network', None),
+                ('fixed_subnet', None),
+                ('http_proxy', None),
+                ('https_proxy', None),
+                ('labels', {}),
+                ('master_flavor_id', None),
+                ('no_proxy', None)):
+            if key in cluster_template:
+                ret[key] = cluster_template.pop(key, default)
+
+        for key in (
+                'apiserver_port',
+                'cluster_distro',
+                'coe',
+                'created_at',
+                'dns_nameserver',
+                'docker_volume_size',
+                'external_network_id',
+                'flavor_id',
+                'image_id',
+                'insecure_registry',
+                'keypair_id',
+                'name',
+                'network_driver',
+                'server_type',
+                'updated_at',
+                'volume_driver'):
+            ret[key] = cluster_template.pop(key)
+
+        ret['properties'] = cluster_template
+        return ret
+
+    def _normalize_magnum_services(self, magnum_services):
+        ret = []
+        for magnum_service in magnum_services:
+            ret.append(self._normalize_magnum_service(magnum_service))
+        return ret
+
+    def _normalize_magnum_service(self, magnum_service):
+        """Normalize Magnum magnum_services."""
+        magnum_service = magnum_service.copy()
+
+        # Discard noise
+        magnum_service.pop('links', None)
+        magnum_service.pop('human_id', None)
+        # model_name is a magnumclient-ism
+        magnum_service.pop('model_name', None)
+
+        ret = munch.Munch(location=self._get_current_location())
+
+        for key in (
+                'binary',
+                'created_at',
+                'disabled_reason',
+                'host',
+                'id',
+                'report_count',
+                'state',
+                'updated_at'):
+            ret[key] = magnum_service.pop(key)
+        ret['properties'] = magnum_service
+        return ret
+
+    def _normalize_stacks(self, stacks):
+        """Normalize Heat Stacks"""
+        ret = []
+        for stack in stacks:
+            ret.append(self._normalize_stack(stack))
+        return ret
+
+    def _normalize_stack(self, stack):
+        """Normalize Heat Stack"""
+        stack = stack.copy()
+
+        # Discard noise
+        stack.pop('HUMAN_ID', None)
+        stack.pop('human_id', None)
+        stack.pop('NAME_ATTR', None)
+        stack.pop('links', None)
+        # Discard things heatclient adds that aren't in the REST
+        stack.pop('action', None)
+        stack.pop('status', None)
+        stack.pop('identifier', None)
+
+        stack_status = stack.pop('stack_status')
+        (action, status) = stack_status.split('_')
+
+        ret = munch.Munch(
+            id=stack.pop('id'),
+            location=self._get_current_location(),
+            action=action,
+            status=status,
+        )
+        if not self.strict_mode:
+            ret['stack_status'] = stack_status
+
+        for (new_name, old_name) in (
+                ('name', 'stack_name'),
+                ('created_at', 'creation_time'),
+                ('deleted_at', 'deletion_time'),
+                ('updated_at', 'updated_time'),
+                ('description', 'description'),
+                ('is_rollback_enabled', 'disable_rollback'),
+                ('parent', 'parent'),
+                ('notification_topics', 'notification_topics'),
+                ('parameters', 'parameters'),
+                ('outputs', 'outputs'),
+                ('owner', 'stack_owner'),
+                ('status_reason', 'stack_status_reason'),
+                ('stack_user_project_id', 'stack_user_project_id'),
+                ('tempate_description', 'template_description'),
+                ('timeout_mins', 'timeout_mins'),
+                ('tags', 'tags')):
+            value = stack.pop(old_name, None)
+            ret[new_name] = value
+            if not self.strict_mode:
+                ret[old_name] = value
+        ret['identifier'] = '{name}/{id}'.format(
+            name=ret['name'], id=ret['id'])
+        ret['properties'] = stack
+        return ret
