@@ -449,11 +449,6 @@ class NeutronFloatingIPUpdate(task_manager.Task):
         return client.neutron_client.update_floatingip(**self.args)
 
 
-class FloatingIPPoolList(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.floating_ip_pools.list()
-
-
 class SubnetCreate(task_manager.Task):
     def main(self, client):
         return client.neutron_client.create_subnet(**self.args)
@@ -704,31 +699,6 @@ class RolesForUser(task_manager.Task):
         return client.keystone_client.roles.roles_for_user(**self.args)
 
 
-class StackList(task_manager.Task):
-    def main(self, client):
-        return client.heat_client.stacks.list()
-
-
-class StackCreate(task_manager.Task):
-    def main(self, client):
-        return client.heat_client.stacks.create(**self.args)
-
-
-class StackUpdate(task_manager.Task):
-    def main(self, client):
-        return client.heat_client.stacks.update(**self.args)
-
-
-class StackDelete(task_manager.Task):
-    def main(self, client):
-        return client.heat_client.stacks.delete(self.args['id'])
-
-
-class StackGet(task_manager.Task):
-    def main(self, client):
-        return client.heat_client.stacks.get(**self.args)
-
-
 class ZoneList(task_manager.Task):
     def main(self, client):
         return client.designate_client.zones.list()
@@ -824,32 +794,6 @@ class NeutronQuotasDelete(task_manager.Task):
         return client.neutron_client.delete_quota(**self.args)
 
 
-class ClusterTemplateList(task_manager.Task):
-    def main(self, client):
-        return client.magnum_client.baymodels.list(**self.args)
-
-
-class ClusterTemplateCreate(task_manager.Task):
-    def main(self, client):
-        return client.magnum_client.baymodels.create(**self.args)
-
-
-class ClusterTemplateDelete(task_manager.Task):
-    def main(self, client):
-        return client.magnum_client.baymodels.delete(self.args['id'])
-
-
-class ClusterTemplateUpdate(task_manager.Task):
-    def main(self, client):
-        return client.magnum_client.baymodels.update(
-            self.args['id'], self.args['patch'])
-
-
-class MagnumServicesList(task_manager.Task):
-    def main(self, client):
-        return client.magnum_client.mservices.list(detail=False)
-
-
 class NovaLimitsGet(task_manager.Task):
     def main(self, client):
         return client.nova_client.limits.get(**self.args).to_dict()
