@@ -29,7 +29,7 @@ class TestClusterTemplate(base.BaseFunctionalTestCase):
 
     def setUp(self):
         super(TestClusterTemplate, self).setUp()
-        if not self.demo_cloud.has_service('container-infra'):
+        if not self.user_cloud.has_service('container-infra'):
             self.skipTest('Container service not supported by cloud')
         self.ct = None
 
@@ -58,10 +58,10 @@ class TestClusterTemplate(base.BaseFunctionalTestCase):
         # add keypair to nova
         with open('%s/id_rsa_shade.pub' % ssh_directory) as f:
             key_content = f.read()
-            self.demo_cloud.create_keypair('testkey', key_content)
+            self.user_cloud.create_keypair('testkey', key_content)
 
         # Test we can create a cluster_template and we get it returned
-        self.ct = self.demo_cloud.create_cluster_template(
+        self.ct = self.user_cloud.create_cluster_template(
             name=name, image_id=image_id,
             keypair_id=keypair_id, coe=coe)
         self.assertEqual(self.ct['name'], name)
@@ -74,40 +74,40 @@ class TestClusterTemplate(base.BaseFunctionalTestCase):
         self.assertEqual(self.ct['server_type'], server_type)
 
         # Test that we can list cluster_templates
-        cluster_templates = self.demo_cloud.list_cluster_templates()
+        cluster_templates = self.user_cloud.list_cluster_templates()
         self.assertIsNotNone(cluster_templates)
 
         # Test we get the same cluster_template with the
         # get_cluster_template method
-        cluster_template_get = self.demo_cloud.get_cluster_template(
+        cluster_template_get = self.user_cloud.get_cluster_template(
             self.ct['uuid'])
         self.assertEqual(cluster_template_get['uuid'], self.ct['uuid'])
 
         # Test the get method also works by name
-        cluster_template_get = self.demo_cloud.get_cluster_template(name)
+        cluster_template_get = self.user_cloud.get_cluster_template(name)
         self.assertEqual(cluster_template_get['name'], self.ct['name'])
 
         # Test we can update a field on the cluster_template and only that
         # field is updated
-        cluster_template_update = self.demo_cloud.update_cluster_template(
+        cluster_template_update = self.user_cloud.update_cluster_template(
             self.ct['uuid'], 'replace', tls_disabled=True)
         self.assertEqual(
             cluster_template_update['uuid'], self.ct['uuid'])
         self.assertEqual(cluster_template_update['tls_disabled'], True)
 
         # Test we can delete and get True returned
-        cluster_template_delete = self.demo_cloud.delete_cluster_template(
+        cluster_template_delete = self.user_cloud.delete_cluster_template(
             self.ct['uuid'])
         self.assertTrue(cluster_template_delete)
 
     def cleanup(self, name):
         if self.ct:
             try:
-                self.demo_cloud.delete_cluster_template(self.ct['name'])
+                self.user_cloud.delete_cluster_template(self.ct['name'])
             except:
                 pass
 
         # delete keypair
-        self.demo_cloud.delete_keypair('testkey')
+        self.user_cloud.delete_keypair('testkey')
         os.unlink('/tmp/.ssh/id_rsa_shade')
         os.unlink('/tmp/.ssh/id_rsa_shade.pub')
