@@ -59,6 +59,26 @@ _ServiceData = collections.namedtuple(
     'json_response_v3, json_response_v2, json_request')
 
 
+_EndpointDataV3 = collections.namedtuple(
+    'EndpointData',
+    'endpoint_id, service_id, interface, region, url, enabled, '
+    'json_response, json_request')
+
+
+_EndpointDataV2 = collections.namedtuple(
+    'EndpointData',
+    'endpoint_id, service_id, region, public_url, internal_url, '
+    'admin_url, v3_endpoint_list, json_response, '
+    'json_request')
+
+
+# NOTE(notmorgan): Shade does not support domain-specific roles
+# This should eventually be fixed if it becomes a main-stream feature.
+_RoleData = collections.namedtuple(
+    'RoleData',
+    'role_id, role_name, json_response, json_request')
+
+
 class BaseTestCase(base.TestCase):
 
     def setUp(self, cloud_config_fixture='clouds.yaml'):
@@ -154,16 +174,20 @@ class RequestsMockTestCase(BaseTestCase):
         self.__register_uris_called = False
 
     def get_mock_url(self, service_type, interface, resource=None,
-                     append=None, base_url_append=None):
+                     append=None, base_url_append=None,
+                     qs_elements=None):
         endpoint_url = self.cloud.endpoint_for(
             service_type=service_type, interface=interface)
         to_join = [endpoint_url]
+        qs = ''
         if base_url_append:
             to_join.append(base_url_append)
         if resource:
             to_join.append(resource)
         to_join.extend(append or [])
-        return '/'.join(to_join)
+        if qs_elements is not None:
+            qs = '?%s' % '&'.join(qs_elements)
+        return '%(uri)s%(qs)s' % {'uri': '/'.join(to_join), 'qs': qs}
 
     def mock_for_keystone_projects(self, project=None, v3=True,
                                    list_get=False, id_get=False,
@@ -216,12 +240,12 @@ class RequestsMockTestCase(BaseTestCase):
         return project_list
 
     def _get_project_data(self, project_name=None, enabled=None,
-                          description=None, v3=True):
+                          domain_id=None, description=None, v3=True):
         project_name = project_name or self.getUniqueString('projectName')
         project_id = uuid.uuid4().hex
         response = {'id': project_id, 'name': project_name}
         request = {'name': project_name}
-        domain_id = uuid.uuid4().hex if v3 else None
+        domain_id = (domain_id or uuid.uuid4().hex) if v3 else None
         if domain_id:
             request['domain_id'] = domain_id
             response['domain_id'] = domain_id
@@ -317,6 +341,60 @@ class RequestsMockTestCase(BaseTestCase):
                             {'service': response},
                             {'OS-KSADM:service': response}, request)
 
+    def _get_endpoint_v3_data(self, service_id=None, region=None,
+                              url=None, interface=None, enabled=True):
+        endpoint_id = uuid.uuid4().hex
+        service_id = service_id or uuid.uuid4().hex
+        region = region or uuid.uuid4().hex
+        url = url or 'https://example.com/'
+        interface = interface or uuid.uuid4().hex
+
+        response = {'id': endpoint_id, 'service_id': service_id,
+                    'region': region, 'interface': interface,
+                    'url': url, 'enabled': enabled}
+        request = response.copy()
+        request.pop('id')
+        response['region_id'] = response['region']
+        return _EndpointDataV3(endpoint_id, service_id, interface, region,
+                               url, enabled, {'endpoint': response},
+                               {'endpoint': request})
+
+    def _get_endpoint_v2_data(self, service_id=None, region=None,
+                              public_url=None, admin_url=None,
+                              internal_url=None):
+        endpoint_id = uuid.uuid4().hex
+        service_id = service_id or uuid.uuid4().hex
+        region = region or uuid.uuid4().hex
+        response = {'id': endpoint_id, 'service_id': service_id,
+                    'region': region}
+        v3_endpoints = {}
+        if admin_url:
+            response['adminURL'] = admin_url
+            v3_endpoints['admin'] = self._get_endpoint_v3_data(
+                service_id, region, public_url, interface='admin')
+        if internal_url:
+            response['internalURL'] = internal_url
+            v3_endpoints['internal'] = self._get_endpoint_v3_data(
+                service_id, region, internal_url, interface='internal')
+        if public_url:
+            response['publicURL'] = public_url
+            v3_endpoints['public'] = self._get_endpoint_v3_data(
+                service_id, region, public_url, interface='public')
+        request = response.copy()
+        request.pop('id')
+        return _EndpointDataV2(endpoint_id, service_id, region, public_url,
+                               internal_url, admin_url, v3_endpoints,
+                               {'endpoint': response}, {'endpoint': request})
+
+    def _get_role_data(self, role_name=None):
+        role_id = uuid.uuid4().hex
+        role_name = role_name or uuid.uuid4().hex
+        request = {'name': role_name}
+        response = request.copy()
+        response['id'] = role_id
+        return _RoleData(role_id, role_name, {'role': response},
+                         {'role': request})
+
     def use_keystone_v3(self):
         self.adapter = self.useFixture(rm_fixture.Fixture())
         self.calls = []
@@ -477,12 +555,10 @@ class RequestsMockTestCase(BaseTestCase):
                 zip(self.calls, self.adapter.request_history)):
             if stop_after and x > stop_after:
                 break
+
             self.assertEqual(
-                call['method'], history.method,
-                'Method mismatch on call {index}'.format(index=x))
-            self.assertEqual(
-                call['url'], history.url,
-                'URL mismatch on call {index}'.format(index=x))
+                (call['method'], call['url']), (history.method, history.url),
+                'REST mismatch on call {index}'.format(index=x))
             if 'json' in call:
                 self.assertEqual(
                     call['json'], history.json(),
