@@ -17,7 +17,6 @@ test_create_server
 Tests for the `create_server` command.
 """
 
-from mock import patch, Mock
 import mock
 from shade import meta
 from shade import OpenStackCloud
@@ -28,148 +27,126 @@ from shade.tests.unit import base
 
 class TestCreateServer(base.RequestsMockTestCase):
 
-    def test_create_server_with_create_exception(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_with_create_exception(self, mock_nova):
         """
         Test that an exception in the novaclient create raises an exception in
         create_server.
         """
-        with patch("shade.OpenStackCloud.nova_client"):
-            config = {
-                "servers.create.side_effect": Exception("exception"),
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertRaises(
-                OpenStackCloudException, self.cloud.create_server,
-                'server-name', {'id': 'image-id'}, {'id': 'flavor-id'})
+        mock_nova.servers.create.side_effect = Exception("exception")
+        self.assertRaises(
+            OpenStackCloudException, self.cloud.create_server,
+            'server-name', {'id': 'image-id'}, {'id': 'flavor-id'})
 
-    def test_create_server_with_get_exception(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_with_get_exception(self, mock_nova):
         """
         Test that an exception when attempting to get the server instance via
         the novaclient raises an exception in create_server.
         """
 
-        with patch("shade.OpenStackCloud.nova_client"):
-            config = {
-                "servers.create.return_value": Mock(status="BUILD"),
-                "servers.get.side_effect": Exception("exception")
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertRaises(
-                OpenStackCloudException, self.cloud.create_server,
-                'server-name', {'id': 'image-id'}, {'id': 'flavor-id'})
+        mock_nova.servers.create.return_value = mock.Mock(status="BUILD")
+        mock_nova.servers.get.side_effect = Exception("exception")
+        self.assertRaises(
+            OpenStackCloudException, self.cloud.create_server,
+            'server-name', {'id': 'image-id'}, {'id': 'flavor-id'})
 
-    def test_create_server_with_server_error(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_with_server_error(self, mock_nova):
         """
         Test that a server error before we return or begin waiting for the
         server instance spawn raises an exception in create_server.
         """
         build_server = fakes.FakeServer('1234', '', 'BUILD')
         error_server = fakes.FakeServer('1234', '', 'ERROR')
-        with patch("shade.OpenStackCloud.nova_client"):
-            config = {
-                "servers.create.return_value": build_server,
-                "servers.get.return_value": error_server,
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertRaises(
-                OpenStackCloudException, self.cloud.create_server,
-                'server-name', {'id': 'image-id'}, {'id': 'flavor-id'})
+        mock_nova.servers.create.return_value = build_server
+        mock_nova.servers.get.return_value = error_server
+        self.assertRaises(
+            OpenStackCloudException, self.cloud.create_server,
+            'server-name', {'id': 'image-id'}, {'id': 'flavor-id'})
 
-    def test_create_server_wait_server_error(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_wait_server_error(self, mock_nova):
         """
         Test that a server error while waiting for the server to spawn
         raises an exception in create_server.
         """
-        with patch("shade.OpenStackCloud.nova_client"):
-            build_server = fakes.FakeServer('1234', '', 'BUILD')
-            error_server = fakes.FakeServer('1234', '', 'ERROR')
-            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
-                                                    '1.1.1.1', '2.2.2.2',
-                                                    '5678')
-            config = {
-                "servers.create.return_value": build_server,
-                "servers.get.return_value": build_server,
-                "servers.list.side_effect": [
-                    [build_server], [error_server]],
-                "floating_ips.list.return_value": [fake_floating_ip]
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertRaises(
-                OpenStackCloudException,
-                self.cloud.create_server,
-                'server-name', dict(id='image-id'),
-                dict(id='flavor-id'), wait=True)
+        build_server = fakes.FakeServer('1234', '', 'BUILD')
+        error_server = fakes.FakeServer('1234', '', 'ERROR')
+        fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                '1.1.1.1', '2.2.2.2',
+                                                '5678')
+        mock_nova.servers.create.return_value = build_server
+        mock_nova.servers.get.return_value = build_server
+        mock_nova.servers.list.side_effect = [[build_server], [error_server]]
+        mock_nova.floating_ips.list.return_value = [fake_floating_ip]
+        self.assertRaises(
+            OpenStackCloudException,
+            self.cloud.create_server,
+            'server-name', dict(id='image-id'),
+            dict(id='flavor-id'), wait=True)
 
-    def test_create_server_with_timeout(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_with_timeout(self, mock_nova):
         """
         Test that a timeout while waiting for the server to spawn raises an
         exception in create_server.
         """
-        with patch("shade.OpenStackCloud.nova_client"):
-            fake_server = fakes.FakeServer('1234', '', 'BUILD')
-            config = {
-                "servers.create.return_value": fake_server,
-                "servers.get.return_value": fake_server,
-                "servers.list.return_value": [fake_server],
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertRaises(
-                OpenStackCloudTimeout,
-                self.cloud.create_server,
-                'server-name',
-                dict(id='image-id'), dict(id='flavor-id'),
-                wait=True, timeout=0.01)
+        fake_server = fakes.FakeServer('1234', '', 'BUILD')
+        mock_nova.servers.create.return_value = fake_server
+        mock_nova.servers.get.return_value = fake_server
+        mock_nova.servers.list.return_value = [fake_server]
+        self.assertRaises(
+            OpenStackCloudTimeout,
+            self.cloud.create_server,
+            'server-name',
+            dict(id='image-id'), dict(id='flavor-id'),
+            wait=True, timeout=0.01)
 
-    def test_create_server_no_wait(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_no_wait(self, mock_nova):
         """
         Test that create_server with no wait and no exception in the
         novaclient create call returns the server instance.
         """
-        with patch("shade.OpenStackCloud.nova_client"):
-            fake_server = fakes.FakeServer('1234', '', 'BUILD')
-            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
-                                                    '1.1.1.1', '2.2.2.2',
-                                                    '5678')
-            config = {
-                "servers.create.return_value": fake_server,
-                "servers.get.return_value": fake_server,
-                "floating_ips.list.return_value": [fake_floating_ip]
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertEqual(
-                self.cloud._normalize_server(
-                    meta.obj_to_dict(fake_server)),
-                self.cloud.create_server(
-                    name='server-name',
-                    image=dict(id='image=id'),
-                    flavor=dict(id='flavor-id')))
+        fake_server = fakes.FakeServer('1234', '', 'BUILD')
+        fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                '1.1.1.1', '2.2.2.2',
+                                                '5678')
+        mock_nova.servers.create.return_value = fake_server
+        mock_nova.servers.get.return_value = fake_server
+        mock_nova.floating_ips.list.return_value = [fake_floating_ip]
+        self.assertEqual(
+            self.cloud._normalize_server(
+                meta.obj_to_dict(fake_server)),
+            self.cloud.create_server(
+                name='server-name',
+                image=dict(id='image=id'),
+                flavor=dict(id='flavor-id')))
 
-    def test_create_server_with_admin_pass_no_wait(self):
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    def test_create_server_with_admin_pass_no_wait(self, mock_nova):
         """
         Test that a server with an admin_pass passed returns the password
         """
-        with patch("shade.OpenStackCloud.nova_client"):
-            fake_server = fakes.FakeServer('1234', '', 'BUILD')
-            fake_create_server = fakes.FakeServer('1234', '', 'BUILD',
-                                                  adminPass='ooBootheiX0edoh')
-            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
-                                                    '1.1.1.1', '2.2.2.2',
-                                                    '5678')
-            config = {
-                "servers.create.return_value": fake_create_server,
-                "servers.get.return_value": fake_server,
-                "floating_ips.list.return_value": [fake_floating_ip]
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.assertEqual(
-                self.cloud._normalize_server(
-                    meta.obj_to_dict(fake_create_server)),
-                self.cloud.create_server(
-                    name='server-name', image=dict(id='image=id'),
-                    flavor=dict(id='flavor-id'), admin_pass='ooBootheiX0edoh'))
+        fake_server = fakes.FakeServer('1234', '', 'BUILD')
+        fake_create_server = fakes.FakeServer('1234', '', 'BUILD',
+                                              adminPass='ooBootheiX0edoh')
+        fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                '1.1.1.1', '2.2.2.2',
+                                                '5678')
+        mock_nova.servers.create.return_value = fake_create_server
+        mock_nova.servers.get.return_value = fake_server
+        mock_nova.floating_ips.list.return_value = [fake_floating_ip]
+        self.assertEqual(
+            self.cloud._normalize_server(
+                meta.obj_to_dict(fake_create_server)),
+            self.cloud.create_server(
+                name='server-name', image=dict(id='image=id'),
+                flavor=dict(id='flavor-id'), admin_pass='ooBootheiX0edoh'))
 
-    @patch.object(OpenStackCloud, "wait_for_server")
-    @patch.object(OpenStackCloud, "nova_client")
+    @mock.patch.object(OpenStackCloud, "wait_for_server")
+    @mock.patch.object(OpenStackCloud, "nova_client")
     def test_create_server_with_admin_pass_wait(self, mock_nova, mock_wait):
         """
         Test that a server with an admin_pass passed returns the password
@@ -199,8 +176,8 @@ class TestCreateServer(base.RequestsMockTestCase):
                 meta.obj_to_dict(fake_server_with_pass))
         )
 
-    @patch.object(OpenStackCloud, "get_active_server")
-    @patch.object(OpenStackCloud, "get_server")
+    @mock.patch.object(OpenStackCloud, "get_active_server")
+    @mock.patch.object(OpenStackCloud, "get_server")
     def test_wait_for_server(self, mock_get_server, mock_get_active_server):
         """
         Test that waiting for a server returns the server instance when
@@ -233,8 +210,8 @@ class TestCreateServer(base.RequestsMockTestCase):
 
         self.assertEqual('ACTIVE', server['status'])
 
-    @patch.object(OpenStackCloud, 'wait_for_server')
-    @patch.object(OpenStackCloud, 'nova_client')
+    @mock.patch.object(OpenStackCloud, 'wait_for_server')
+    @mock.patch.object(OpenStackCloud, 'nova_client')
     def test_create_server_wait(self, mock_nova, mock_wait):
         """
         Test that create_server with a wait actually does the wait.
@@ -252,37 +229,35 @@ class TestCreateServer(base.RequestsMockTestCase):
             nat_destination=None,
         )
 
-    @patch('time.sleep')
-    def test_create_server_no_addresses(self, mock_sleep):
+    @mock.patch.object(OpenStackCloud, 'add_ips_to_server')
+    @mock.patch.object(OpenStackCloud, 'nova_client')
+    @mock.patch('time.sleep')
+    def test_create_server_no_addresses(
+            self, mock_sleep, mock_nova, mock_add_ips_to_server):
         """
         Test that create_server with a wait throws an exception if the
         server doesn't have addresses.
         """
-        with patch("shade.OpenStackCloud.nova_client"):
-            build_server = fakes.FakeServer('1234', '', 'BUILD')
-            fake_server = fakes.FakeServer('1234', '', 'ACTIVE')
-            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
-                                                    '1.1.1.1', '2.2.2.2',
-                                                    '5678')
-            config = {
-                "servers.create.return_value": build_server,
-                "servers.get.return_value": [build_server, None],
-                "servers.list.side_effect": [
-                    [build_server], [fake_server]],
-                "servers.delete.return_value": None,
-                "floating_ips.list.return_value": [fake_floating_ip]
-            }
-            OpenStackCloud.nova_client = Mock(**config)
-            self.cloud._SERVER_AGE = 0
-            with patch.object(OpenStackCloud, "add_ips_to_server",
-                              return_value=fake_server):
-                self.assertRaises(
-                    OpenStackCloudException, self.cloud.create_server,
-                    'server-name', {'id': 'image-id'}, {'id': 'flavor-id'},
-                    wait=True)
+        build_server = fakes.FakeServer('1234', '', 'BUILD')
+        fake_server = fakes.FakeServer('1234', '', 'ACTIVE')
+        fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                '1.1.1.1', '2.2.2.2',
+                                                '5678')
+        mock_nova.servers.create.return_value = build_server
+        mock_nova.servers.get.return_value = [build_server, None]
+        mock_nova.servers.list.side_effect = [[build_server], [fake_server]]
+        mock_nova.servers.delete.return_value = None
+        mock_nova.floating_ips.list.return_value = [fake_floating_ip]
+        mock_add_ips_to_server.return_value = fake_server
+        self.cloud._SERVER_AGE = 0
 
-    @patch('shade.OpenStackCloud.nova_client')
-    @patch('shade.OpenStackCloud.get_network')
+        self.assertRaises(
+            OpenStackCloudException, self.cloud.create_server,
+            'server-name', {'id': 'image-id'}, {'id': 'flavor-id'},
+            wait=True)
+
+    @mock.patch('shade.OpenStackCloud.nova_client')
+    @mock.patch('shade.OpenStackCloud.get_network')
     def test_create_server_network_with_no_nics(self, mock_get_network,
                                                 mock_nova):
         """
@@ -294,8 +269,8 @@ class TestCreateServer(base.RequestsMockTestCase):
             dict(id='image-id'), dict(id='flavor-id'), network='network-name')
         mock_get_network.assert_called_once_with(name_or_id='network-name')
 
-    @patch('shade.OpenStackCloud.nova_client')
-    @patch('shade.OpenStackCloud.get_network')
+    @mock.patch('shade.OpenStackCloud.nova_client')
+    @mock.patch('shade.OpenStackCloud.get_network')
     def test_create_server_network_with_empty_nics(self,
                                                    mock_get_network,
                                                    mock_nova):
